DOMDOM

Товары для дома и уюта Наш интернет магазин в настоящее время находится в стадии приема товара, мы полностью будем готовы к продаже товара в ближайшее время. Спасибо за проявленный интерес к нашему магазину. +7 777 941 33 23
+7 777 153 72 22 Казыбек Би, 143
Акбулак (1 мкр.) ТД "ИРС"

ссылка
пробел

### Оплата и доставка Оплата и доставка. Доставка выбранного товара возможна: - доставка нашим курьером по городу Тараз, - доставка курьерской службой по всему Казахстану, - самовывозом с наших торговых точек. Доставка нашим курьером по городу Тараз. По городу Тараз возможна доставка нашими курьерами бесплатно (заказы от 10000 тг.), или платно 500 тг. (при заказе менее 10000 тг.). При такой доставке оплата производится непосредственно курьеру при получении и проверке товара. В случаи отказа от товара доставка не оплачивается. То есть если товар вам не подошел, или его качество не понравилось, вы ничего не платите. Сроки доставки при его наличии на складе до двух рабочих дней. Доставка курьерской службой по Казахстану. Доставка производится любой из перечисленных курьерских служб ExLine DHL КАЗПОЧТА или любой службой доставки указанной клиентом. Cтоимость доставки согласно тарифам выбранной службы доставки, оплачиваются вами в момент заказа. Сроки доставки зависят от наличия товара на складе и времени доставки, и составляют от 3 до 30 дней. Самовывоз. Производится с торговых точек MultiDom, по адресам: - город Тараз, микрорайон Акбулак (1мкр.) ТД "ИРС" (Торговый центр), 2-ой этаж, - город Тараз, улица Казыбек би 143, TД "Скарлетт". Оплата производится при получение и проверке товара, в кассу магазина. Срок упаковки и доставки заказа на выбранную торговую точку до двух рабочих дней. ### О компании Магазин MultiDoM существует и работает c 2014 года для тех, кто любит свою семью и свой дом, для тех, кто наслаждается процессом обустройства своего быта. MultiDoM - специализированный магазин товаров для дома, который предлагает широкий продуманный ассортимент для создания домашнего уюта и стиля, обустройства интерьера, новинки и тренды, возможность получить грамотную консультацию. Сегодня примерно треть ассортимента магазина – это эксклюзивные предложения. В этом мы видим залог успеха: предлагать покупателям коллекции, которых нет в других магазинах. Таким образом,MultiDoM дает возможность покупателям проявить свою фантазию, индивидуальность в создании дизайна и интерьера уютного дома. Наш магазин товаров для дома предлагает от 15 до 25 тысяч наименований товаров. Наиболее широкий ассортимент представлен в следующих группах: «Посуда и кухонные принадлежности», «Товары для ванной комнаты» «Домашний текстиль», «Товары для уборки и хранения», «Декор и интерьер». Наш магазин предоставляет возможности проявить себя, создать то неповторимое состояние в доме, которое и называют уютом, постоянно пытается стать еще более интересным для своих покупателей, улавливать их потребности, искать в мире то, что им нужно. ### Адреса Адрес: Казыбек Би, 143 ТД "Скарлетт"; Акбулак (1 мкр.) ТД "ИРС", 2 этаж; Мынбулак (9 мкр.) ТД "Диана". Телефон: 8 7262 34 36 87 +7 777 941 33 23 +7 777 153 72 22 e-mail: multidom-taraz-2014@mail.ru Мы в соцсетях: ​ | ### Новости #### 2015-11-10 / Запуск сайта Сегодня произшло грандиозное событие/ завезли окорочка Подробнее #### 2015-11-02 / Поступление ваз Новый ассортимент ваз. Магазин пополнился оллекцией китайских ваз Подробнее ### Партнерам Наш интернет- магазин приглашает к сотрудничеству поставщиков качественных и интересных товаров для дома и интерьера. Рассмотрим все варианты совместной работы. Предложения сотрудничества просим высылать на электронную почту multidom-taraz-2014@mail.ru ### Напишите нам Ваше имя: Ваше e-mail: Тема письма: Текст сообщения: